@@ -9,9 +9,9 @@ var searchData=
   ['major_6',['major',['../structdsam_1_1DsamDevice_1_1FirmwareVersion.html#a5d92791dcd3ae374f482d22a09b68494',1,'dsam::DsamDevice::FirmwareVersion']]],
   ['majornumber_7',['majorNumber',['../structperipheral_1_1PackageInfo_1_1FirmwareInfo_1_1Version.html#a49255f9682d5a3194298921742395c13',1,'peripheral::PackageInfo::FirmwareInfo::Version']]],
   ['manualtransferenabled_8',['manualTransferEnabled',['../structpdumodel_1_1TransferSwitch_1_1Settings.html#ac4aee0109ab22f80787cf119edc7006d',1,'pdumodel::TransferSwitch::Settings']]],
-  ['manufacturer_9',['manufacturer',['../structsmartcard_1_1CardReader_1_1MetaData.html#a094b00a9ff4bd2bdf086027344b37983',1,'smartcard::CardReader::MetaData::manufacturer()'],['../structserial_1_1GsmModem_1_1Information.html#ad915f3f98ad452e0a3ce04e3470b3e0f',1,'serial::GsmModem::Information::manufacturer()'],['../structsmartlock_1_1Keypad_1_1MetaData.html#a4f014e9739f79ecdcfab448557d63fca',1,'smartlock::Keypad::MetaData::manufacturer()'],['../structpdumodel_1_1Nameplate.html#adb9bd1b07c2e58fe543879993ae4ee7e',1,'pdumodel::Nameplate::manufacturer()']]],
+  ['manufacturer_9',['manufacturer',['../structpdumodel_1_1Nameplate.html#adb9bd1b07c2e58fe543879993ae4ee7e',1,'pdumodel::Nameplate::manufacturer()'],['../structusb_1_1UsbDevice.html#aad3007fbaffe06cb554fa104d9c8b993',1,'usb::UsbDevice::manufacturer()'],['../structsmartlock_1_1Keypad_1_1MetaData.html#a4f014e9739f79ecdcfab448557d63fca',1,'smartlock::Keypad::MetaData::manufacturer()'],['../structserial_1_1GsmModem_1_1Information.html#ad915f3f98ad452e0a3ce04e3470b3e0f',1,'serial::GsmModem::Information::manufacturer()'],['../structsmartcard_1_1CardReader_1_1MetaData.html#a094b00a9ff4bd2bdf086027344b37983',1,'smartcard::CardReader::MetaData::manufacturer()']]],
   ['mar_10',['MAR',['../interfaceevent_1_1TimerEventManager.html#a10bd90689f513629b7cedaea59d34df0',1,'event::TimerEventManager']]],
-  ['mask_11',['mask',['../structperipheral_1_1GatewaySensorManager_1_1InterpretationRuleRAW.html#ad1fc64455dec84ed00f7a9793a9d6fa5',1,'peripheral::GatewaySensorManager::InterpretationRuleRAW::mask()'],['../structperipheral_1_1GatewaySensorManager_1_1ModbusValueEncoding8.html#a336802c4de2f8aa8551ed6f5fc5cbe9f',1,'peripheral::GatewaySensorManager::ModbusValueEncoding8::mask()'],['../structperipheral_1_1GatewaySensorManager_1_1InterpretationRuleRangeRAW.html#a0f5ad46070cc314e96c533c2396c2b9d',1,'peripheral::GatewaySensorManager::InterpretationRuleRangeRAW::mask()']]],
+  ['mask_11',['mask',['../structperipheral_1_1GatewaySensorManager_1_1InterpretationRuleRAW.html#ad1fc64455dec84ed00f7a9793a9d6fa5',1,'peripheral::GatewaySensorManager::InterpretationRuleRAW::mask()'],['../structperipheral_1_1GatewaySensorManager_1_1InterpretationRuleRangeRAW.html#a0f5ad46070cc314e96c533c2396c2b9d',1,'peripheral::GatewaySensorManager::InterpretationRuleRangeRAW::mask()'],['../structperipheral_1_1GatewaySensorManager_1_1ModbusValueEncoding8.html#a336802c4de2f8aa8551ed6f5fc5cbe9f',1,'peripheral::GatewaySensorManager::ModbusValueEncoding8::mask()']]],
   ['matchtype_12',['matchType',['../structevent_1_1Engine_1_1Condition.html#adca9b7a0ebb1faf9dea98dc1a493973f',1,'event::Engine::Condition']]],
   ['max_13',['max',['../structperipheral_1_1GatewaySensorManager_1_1InterpretationRuleRangeRAW.html#aa5a77ca16d19f69b62dc9ce1c21bdd91',1,'peripheral::GatewaySensorManager::InterpretationRuleRangeRAW']]],
   ['maxactivepowereddrycontacts_14',['maxActivePoweredDryContacts',['../structperipheral_1_1DeviceManager_1_1Settings.html#aff74119138a4a6195c05ad425bc9bfb3',1,'peripheral::DeviceManager::Settings']]],
@@ -19,7 +19,7 @@ var searchData=
   ['maxamountofscripts_16',['maxAmountOfScripts',['../structluaservice_1_1Environment.html#a0676874c0b953ae9eab7b7acaf2e4040',1,'luaservice::Environment']]],
   ['maxbladetagcount_17',['maxBladeTagCount',['../structassetmgrmodel_1_1AssetStrip_1_1StripInfo.html#a181b7aea3252f3820d47c19c540cf06c',1,'assetmgrmodel::AssetStrip::StripInfo']]],
   ['maxfailedlogins_18',['maxFailedLogins',['../structsecurity_1_1BlockSettings.html#a47c702878415a1e624c8e8acdef0d406',1,'security::BlockSettings']]],
-  ['maximumcurrent_19',['maximumCurrent',['../structpdumodel_1_1OverCurrentProtector_1_1Sensors.html#a5deea4b87a06d52bbb8baa004cf3d05e',1,'pdumodel::OverCurrentProtector::Sensors::maximumCurrent()'],['../structpdumodel_1_1Outlet_1_1Sensors.html#aeeccdd70b97674d3a25c58e9295dbe6a',1,'pdumodel::Outlet::Sensors::maximumCurrent()']]],
+  ['maximumcurrent_19',['maximumCurrent',['../structpdumodel_1_1Outlet_1_1Sensors.html#aeeccdd70b97674d3a25c58e9295dbe6a',1,'pdumodel::Outlet::Sensors::maximumCurrent()'],['../structpdumodel_1_1OverCurrentProtector_1_1Sensors.html#a5deea4b87a06d52bbb8baa004cf3d05e',1,'pdumodel::OverCurrentProtector::Sensors::maximumCurrent()']]],
   ['maxmaintagcount_20',['maxMainTagCount',['../structassetmgrmodel_1_1AssetStrip_1_1StripInfo.html#a19b80bcb0fc02a402a01a9d9728b4495',1,'assetmgrmodel::AssetStrip::StripInfo']]],
   ['maxpwlength_21',['maxPwLength',['../structsecurity_1_1PasswordSettings.html#aa6a9313346b84f66dae132f99f168b72',1,'security::PasswordSettings']]],
   ['maxreading_22',['maxReading',['../structsensors_1_1NumericSensor_1_1MinMax.html#a8d44fba1608d8b5e7dc5f0753fddd034',1,'sensors::NumericSensor::MinMax']]],
@@ -35,7 +35,7 @@ var searchData=
   ['may_32',['MAY',['../interfaceevent_1_1TimerEventManager.html#a99c2b7c6f528e6ae2f598663de5d6df9',1,'event::TimerEventManager']]],
   ['mdnsenabled_33',['mdnsEnabled',['../structdevsettings_1_1Zeroconf_1_1Settings.html#ad4f2b87f770ef25e7ff1e6f5811fbf28',1,'devsettings::Zeroconf::Settings']]],
   ['members_34',['members',['../structpdumodel_1_1OutletGroup_1_1Settings.html#ab0a2e0a081cff83c15569469a9e23826',1,'pdumodel::OutletGroup::Settings']]],
-  ['message_35',['message',['../structdevsettings_1_1Smtp_1_1TestResult.html#ae9e39d1e8be86907e2ea332b8133f589',1,'devsettings::Smtp::TestResult::message()'],['../structlogging_1_1LogEntry.html#a30caf0a77772cf7821de6ec151c5c361',1,'logging::LogEntry::message()'],['../structevent_1_1AlarmManager_1_1Alert.html#a9fb733be775e623afe44d5d8f87ef811',1,'event::AlarmManager::Alert::message()']]],
+  ['message_35',['message',['../structevent_1_1AlarmManager_1_1Alert.html#a9fb733be775e623afe44d5d8f87ef811',1,'event::AlarmManager::Alert::message()'],['../structdevsettings_1_1Smtp_1_1TestResult.html#ae9e39d1e8be86907e2ea332b8133f589',1,'devsettings::Smtp::TestResult::message()'],['../structlogging_1_1LogEntry.html#a30caf0a77772cf7821de6ec151c5c361',1,'logging::LogEntry::message()']]],
   ['meta_36',['meta',['../structwebcam_1_1Image.html#a62ccf274f0e47642dbab5be111e0befe',1,'webcam::Image']]],
   ['metadata_37',['metaData',['../structsmartcard_1_1CardReaderManager_1_1CardReaderEvent.html#a102b2ffb8296896066d2aa51957b4b85',1,'smartcard::CardReaderManager::CardReaderEvent::metaData()'],['../structsmartlock_1_1Keypad_1_1PINEnteredEvent.html#a5dbc03c10c41c45fd0cc14e76d8ffffc',1,'smartlock::Keypad::PINEnteredEvent::metaData()'],['../structsmartlock_1_1KeypadManager_1_1KeypadEvent.html#ad2770b1a5823d4d5dde139fde120482d',1,'smartlock::KeypadManager::KeypadEvent::metaData()'],['../structwebcam_1_1StorageManager_1_1StorageImage.html#a827283151eb066797f477cce687ed84e',1,'webcam::StorageManager::StorageImage::metaData()']]],
   ['metadata_38',['metadata',['../structperipheral_1_1GatewaySensorManager_1_1NumericSensorClass.html#a2321718da5ce0202cf3b5a15a45e07db',1,'peripheral::GatewaySensorManager::NumericSensorClass::metadata()'],['../structdatapush_1_1Sensor.html#aa21c748e8467ef0630542b2e522155dd',1,'datapush::Sensor::metadata()']]],
